@@ -4,6 +4,7 @@ from pathlib import Path
 from typing import Any, Dict, Iterator, Optional, Union
 
 import requests
+from requests.models import Response
 
 from darwin.config import Config
 from darwin.dataset import RemoteDataset
@@ -15,6 +16,7 @@ from darwin.exceptions import (
     NotFound,
     Unauthorized,
 )
+from darwin.types import DarwinVersionNumber
 from darwin.utils import is_project_dir, urljoin
 from darwin.validators import name_taken, validation_error
 
@@ -26,7 +28,7 @@ class Client:
         self.base_url = config.get("global/base_url")
         self.default_team = default_team or config.get("global/default_team")
         self.features: dict = {}
-        self._newer_version = None
+        self._newer_version: Optional[DarwinVersionNumber] = None
 
     def get(
         self, endpoint: str, team: Optional[str] = None, retry: bool = False, raw: bool = False, debug: bool = False
@@ -109,7 +111,7 @@ class Client:
         dict
             Dictionary which contains the server response
         """
-        response = requests.put(urljoin(self.url, endpoint), json=payload, headers=self._get_headers(team))
+        response: Response = requests.put(urljoin(self.url, endpoint), json=payload, headers=self._get_headers(team))
 
         if response.status_code == 401:
             raise Unauthorized()
@@ -122,11 +124,12 @@ class Client:
         if response.status_code != 200 and retry:
             if debug:
                 print(
-                    f"Client get request response ({response.json()}) with unexpected status "
+                    f"Client GET request got response ({response.json()}) with unexpected status "
                     f"({response.status_code}). "
                     f"Client: ({self})"
                     f"Request: (endpoint={endpoint}, payload={payload})"
                 )
+
             time.sleep(10)
             return self.put(endpoint, payload=payload, retry=False)
 
@@ -568,7 +571,7 @@ class Client:
             pass
 
     @property
-    def newer_darwin_version(self):
+    def newer_darwin_version(self) -> Optional[DarwinVersionNumber]:
         return self._newer_version
 
     def __str__(self):
