@@ -8,6 +8,13 @@ def build_image_annotation(annotation_file: dt.AnnotationFile):
             annotation.annotation_class.annotation_type: build_annotation_data(annotation),
             "name": annotation.annotation_class.name,
         }
+
+        if (
+            annotation.annotation_class.annotation_type == "complex_polygon"
+            or annotation.annotation_class.annotation_type == "polygon"
+        ) and "bounding_box" in annotation.data:
+            payload["bounding_box"] = annotation.data["bounding_box"]
+
         annotations.append(payload)
 
     return {
@@ -25,4 +32,7 @@ def build_annotation_data(annotation: dt.Annotation):
     if annotation.annotation_class.annotation_type == "complex_polygon":
         return {"path": annotation.data["paths"]}
 
+    if annotation.annotation_class.annotation_type == "polygon":
+        return dict(filter(lambda item: item[0] != "bounding_box", annotation.data.items()))
+
     return dict(annotation.data)
